@@ -1,21 +1,14 @@
-"""
-Test the pygr API.
-"""
-
 from __future__ import absolute_import, unicode_literals
 
-try:
-    import pygr
-except ImportError:
-    import nose
-    raise nose.SkipTest("pygr is required for these tests")
+import pytest
+pygr = pytest.importorskip("pygr")
 
-import screed
-from screed.DBConstants import fileExtension
-from screed.pygr_api import ScreedSequenceDB, ScreedSequenceDB_ByIndex
-from pickle import dump, load
-from io import StringIO
-import os
+import screed  # nopep8
+from screed.DBConstants import fileExtension  # nopep8
+from screed.pygr_api import ScreedSequenceDB, ScreedSequenceDB_ByIndex  # nopep8
+from pickle import dump, load  # nopep8
+from io import StringIO  # nopep8
+import os  # nopep8
 
 testfa = os.path.join(os.path.dirname(__file__), 'test.fa')
 
